@@ -81,11 +81,12 @@ discharging
 """
 
 from re import findall
-from glob import iglob
 
 import itertools
 import math
-import os
+
+from pathlib import Path
+
 
 BLOCKS = "_▁▂▃▄▅▆▇█"
 CHARGING_CHARACTER = "⚡"
@@ -101,8 +102,7 @@ FULLY_CHARGED = "?"
 
 
 class Py3status:
-    """
-    """
+    """"""
 
     # available configuration parameters
     battery_id = 0
@@ -158,19 +158,19 @@ class Py3status:
         self.last_known_status = ""
         # Guess mode if not set
         if self.measurement_mode is None:
-            if os.path.isdir(self.sys_battery_path):
+            if Path(self.sys_battery_path).is_dir():
                 self.measurement_mode = "sys"
             elif self.py3.check_commands(["acpi"]):
                 self.measurement_mode = "acpi"
 
-        msg = "measurement_mode `{}`".format(self.measurement_mode)
+        msg = f"measurement_mode `{self.measurement_mode}`"
         if self.measurement_mode == "sys":
             self.get_battery_info = self._extract_battery_info_from_sys
         elif self.measurement_mode == "acpi":
             self.get_battery_info = self._extract_battery_info_from_acpi
         else:
-            raise NameError("invalid {}".format(msg))
-        self.py3.log("selected {}".format(msg))
+            raise NameError(f"invalid {msg}")
+        self.py3.log(f"selected {msg}")
 
     def battery_level(self):
         battery_list = self.get_battery_info()
@@ -275,7 +275,7 @@ class Py3status:
         a similar, yet incompatible interface in /proc
         """
 
-        if not os.listdir(self.sys_battery_path):
+        if not any(Path(self.sys_battery_path).iterdir()):
             return []
 
         def _parse_battery_info(sys_path):
@@ -284,7 +284,7 @@ class Py3status:
             int if necessary
             """
             raw_values = {}
-            with open(os.path.join(sys_path, "uevent")) as f:
+            with (sys_path / "uevent").open() as f:
                 for var in f.read().splitlines():
                     k, v = var.split("=")
                     try:
@@ -297,8 +297,9 @@ class Py3status:
 
         bglobs = ["BAT*", "*bat*"]
         path_its = itertools.chain(
-            *[iglob(os.path.join(self.sys_battery_path, bglob)) for bglob in bglobs]
+            *[Path(self.sys_battery_path).glob(bglob) for bglob in bglobs]
         )
+
         for path in path_its:
             r = _parse_battery_info(path)
 
@@ -331,9 +332,7 @@ class Py3status:
             battery = {}
             battery["capacity"] = capacity
             battery["charging"] = "Charging" in r["POWER_SUPPLY_STATUS"]
-            battery["percent_charged"] = int(
-                math.floor(remaining_energy / capacity * 100)
-            )
+            battery["percent_charged"] = math.floor(remaining_energy / capacity * 100)
             if present_rate == 0:
                 # Battery is either full charged or is not discharging
                 battery["time_remaining"] = FULLY_CHARGED
@@ -344,7 +343,7 @@ class Py3status:
                     time_in_secs = remaining_energy / present_rate * 3600
                 battery["time_remaining"] = self._seconds_to_hms(time_in_secs)
 
-            battery["power"] = current_now * voltage_now / 1e12
+            battery["power"] = current_now * voltage_now / 10 ** 12
 
             battery_list.append(battery)
         return battery_list
@@ -356,7 +355,7 @@ class Py3status:
     def _seconds_to_hms(self, secs):
         m, s = divmod(secs, 60)
         h, m = divmod(m, 60)
-        return "%d:%02d:%02d" % (h, m, s)
+        return f"{h}:{int(m):02d}:{int(s):02d}"
 
     def _refresh_battery_info(self, battery_list):
         if type(self.battery_id) == int:
@@ -367,33 +366,29 @@ class Py3status:
             self.power_now = battery["power"]
 
         elif self.battery_id == "all":
-            total_capacity = sum([battery["capacity"] for battery in battery_list])
+            total_capacity = sum(battery["capacity"] for battery in battery_list)
 
             # Average and weigh % charged by the capacities of the batteries so
             # that self.percent_charged properly represents batteries that have
             # different capacities.
             self.percent_charged = int(
                 sum(
-                    [
-                        battery["capacity"]
-                        / total_capacity
-                        * battery["percent_charged"]
-                        for battery in battery_list
-                    ]
+                    battery["capacity"] / total_capacity * battery["percent_charged"]
+                    for battery in battery_list
                 )
             )
 
-            self.charging = any([battery["charging"] for battery in battery_list])
+            self.charging = any(battery["charging"] for battery in battery_list)
 
             # Assumes a system has at max two batteries
             active_battery = None
             inactive_battery = battery_list[:]
-            for battery_id in range(0, len(battery_list)):
+            for battery_id, battery in enumerate(battery_list):
                 if (
-                    battery_list[battery_id]["time_remaining"]
-                    and battery_list[battery_id]["time_remaining"] != FULLY_CHARGED
+                    battery["time_remaining"]
+                    and battery["time_remaining"] != FULLY_CHARGED
                 ):
-                    active_battery = battery_list[battery_id]
+                    active_battery = battery
                     del inactive_battery[battery_id]
 
             # Only one battery will be discharging or charging at a time.
@@ -431,7 +426,7 @@ class Py3status:
             else:
                 self.time_remaining = None
 
-            self.power_now = sum([battery["power"] for battery in battery_list])
+            self.power_now = sum(battery["power"] for battery in battery_list)
 
         if self.time_remaining and self.hide_seconds:
             self.time_remaining = self.time_remaining[:-3]
@@ -439,12 +434,10 @@ class Py3status:
     def _update_ascii_bar(self):
         self.ascii_bar = FULL_BLOCK * int(self.percent_charged / 10)
         if self.charging:
-            self.ascii_bar += EMPTY_BLOCK_CHARGING * (
-                10 - int(self.percent_charged / 10)
-            )
+            self.ascii_bar += EMPTY_BLOCK_CHARGING * (10 - self.percent_charged // 10)
         else:
             self.ascii_bar += EMPTY_BLOCK_DISCHARGING * (
-                10 - int(self.percent_charged / 10)
+                10 - self.percent_charged // 10
             )
 
     def _update_icon(self):
