@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display song currently playing in mpd.
 
 Configuration parameters:
     cache_timeout: how often we refresh this module in seconds (default 2)
     format: template string (see below)
-        (default '{state} [[[{artist}] - {title}]|[{file}]]')
+        (default '{state} [[[{artist} ]- {title}]|[{file}]]')
     hide_on_error: hide the status if an error has occurred (default False)
     hide_when_paused: hide the status if state is paused (default False)
     hide_when_stopped: hide the status if state is stopped (default True)
@@ -15,7 +14,7 @@ Configuration parameters:
         mixer: changes in volume
         options: e.g. repeat mode
         See the MPD protocol documentation for additional events.
-        (default ['player', 'mixer', 'options'])
+        (default ['player', 'playlist', 'mixer', 'options'])
     idle_timeout: force idle to reset every n seconds (default 3600)
     max_width: maximum status length (default 120)
     password: mpd password (default None)
@@ -84,7 +83,7 @@ def song_attr(song, attr):
             duration = int(song["time"])
             if duration > 0:
                 minutes, seconds = divmod(duration, 60)
-                return "{:d}:{:02d}".format(minutes, seconds)
+                return f"{minutes:d}:{seconds:02d}"
             raise ValueError
         except (KeyError, ValueError):
             return ""
@@ -107,12 +106,12 @@ class Py3status:
 
     # available configuration parameters
     cache_timeout = 2
-    format = "{state} [[[{artist}] - {title}]|[{file}]]"
+    format = "{state} [[[{artist} ]- {title}]|[{file}]]"
     hide_on_error = False
     hide_when_paused = False
     hide_when_stopped = True
     host = "localhost"
-    idle_subsystems = ["player", "mixer", "options"]
+    idle_subsystems = ["player", "playlist", "mixer", "options"]
     idle_timeout = 3600
     max_width = 120
     password = None
@@ -152,7 +151,7 @@ class Py3status:
                 if self.use_idle and self.idle_timeout:
                     self.client.idletimeout = self.idle_timeout
             return self.client
-        except (socket.error, ConnectionError, CommandError) as e:
+        except (OSError, ConnectionError, CommandError) as e:
             self.client = None
             raise e
 
@@ -183,7 +182,7 @@ class Py3status:
             (text, state) = self.current_status
 
         if len(text) > self.max_width:
-            text = u"{}...".format(text[: self.max_width - 3])
+            text = "{}...".format(text[: self.max_width - 3])
 
         response = {
             "cached_until": self.py3.time_in(self.cache_timeout),
@@ -217,7 +216,7 @@ class Py3status:
                 else:
                     playlist_info = self._get_mpd().playlistinfo()
                     try:
-                        song = playlist_info[song]
+                        song = self._get_mpd().currentsong() or playlist_info[song]
                     except IndexError:
                         song = {}
                     try:
@@ -244,7 +243,7 @@ class Py3status:
                 else:
                     return
 
-            except (ValueError, socket.error, ConnectionError, CommandError) as e:
+            except (ValueError, OSError, ConnectionError, CommandError) as e:
                 # ValueError can happen when status.get(...) returns None; e.g.
                 # during reversal of playlist
                 if isinstance(e, ValueError):
